package com.example.what_the_fantasy.ui.screens

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Button
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.what_the_fantasy.data.local.DailyQuoteStub
import com.example.what_the_fantasy.data.local.QuoteStub
import com.example.what_the_fantasy.ui.components.NavBar
import com.example.what_the_fantasy.ui.components.QuoteLittle
import com.example.what_the_fantasy.ui.theme.colorBackground

@Composable
fun AccueilPage(
    index: Int,
    navFavorite: (Int) -> Unit,
    navQuiz: (Int) -> Unit,
    navProfil: (Int) -> Unit
) {
    var itemCount by remember { mutableStateOf(15) }
    val dailyQuote = DailyQuoteStub.dailyQuote
    val quotes = QuoteStub.allQuotes.take(itemCount)

    NavBar(
        onAccueil = true,
        index = index,
        navControllerFavorite = navFavorite,
        navControllerAccueil = { },
        navControllerProfil = navProfil,
        navControllerQuiz = navQuiz
    ) {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .background(colorBackground)
        ) {
            LazyColumn(modifier = Modifier.weight(1f)) {
                item{
                    Column {
                        Text(
                            text = "▶ Citation du jour ◀",
                            color = Color.White,
                            fontSize = 24.sp,
                            modifier = Modifier
                                .fillMaxWidth()
                                .padding(16.dp),
                            textAlign = TextAlign.Center
                        )

                        QuoteLittle(dailyQuote)
                    }
                    Text(
                        text = "▶ Suggestions ◀",
                        color = Color.White,
                        fontSize = 24.sp,
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(16.dp),
                        textAlign = TextAlign.Center
                    )
                }
                items(quotes) { quote ->
                    QuoteLittle(quote)
                }
                if (itemCount < QuoteStub.allQuotes.size) {
                    item {
                        LaunchedEffect(itemCount) {
                            itemCount += 15
                        }
                        Box(
                            modifier = Modifier
                                .fillMaxWidth()
                                .padding(16.dp),
                            contentAlignment = Alignment.Center
                        ) {
                            CircularProgressIndicator()
                        }
                    }
                }
            }
        }
    }
}
