package com.example.what_the_fantasy.ui.screens

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Check
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.what_the_fantasy.R
import com.example.what_the_fantasy.data.services.IServices
import com.example.what_the_fantasy.ui.components.SpaceHeightComponent
import com.example.what_the_fantasy.ui.components.TitlePageComponent
import com.example.what_the_fantasy.ui.theme.What_The_FantasyTheme
import com.example.what_the_fantasy.ui.theme.colorBackground
import com.example.what_the_fantasy.ui.theme.gradienBox
import com.example.what_the_fantasy.data.services.ServicesStub
import com.example.what_the_fantasy.ui.components.ErrorMessageProfileComponent
import com.example.what_the_fantasy.ui.components.hashPassword

@Composable
fun SignUpPage(navControllerLogin: () -> Unit, services : IServices) {
    var username by remember { mutableStateOf("") }
    var email by remember { mutableStateOf("") }
    var password by remember { mutableStateOf("") }
    var confirmPassword by remember { mutableStateOf("") }
    var passwordVisible by remember { mutableStateOf(false) }

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(colorBackground),
        contentAlignment = Alignment.Center
    ){
        Column(
            modifier = Modifier
                .fillMaxWidth(0.9f)
                .padding(20.dp)
                .clip(RoundedCornerShape(16.dp))
                .background(gradienBox)
                .padding(20.dp),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {

            TitlePageComponent(R.string.titleSignUp,Color.White)
            IdentifiantTextFieldSign(R.string.IdentifiantLogin,identifiant = username,onValueChange = { username = it })
            EmailTextFieldSign(R.string.EmailSignUp, email, onValueChange = { email = it })
            PassWdTextFieldSign(R.string.PasswdLogin,password, onValueChange = { password = it },passwordVisible,onPasswordVisibilityChange = { passwordVisible = !passwordVisible })
            PassWdConfirmTextFieldSign(R.string.ConfirmPassWdSignUp,confirmPassword,onValueChange = { confirmPassword = it },passwordVisible,onPasswordVisibilityChange = { passwordVisible = !passwordVisible })
            SpaceHeightComponent(16)
            ConnexionButtonSign(R.string.ButtonSignUp,18, Color.White, Color.Black, username, email, password, confirmPassword, services, navControllerLogin)
            SpaceHeightComponent(16)
            ReturnLogin(R.string.ButtonLogin,12, Color.White, navController = navControllerLogin)

        }
    }
}




@Composable
fun IdentifiantTextFieldSign(textIdentifiantResId : Int, identifiant: String, onValueChange: (String) -> Unit){
    val textIdentifiant = stringResource(id = textIdentifiantResId)

    Column(modifier = Modifier.padding(top = 16.dp)) {
        OutlinedTextField(
            value = identifiant,
            onValueChange = onValueChange,
            label = { Text(textIdentifiant) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Text),
            shape = RoundedCornerShape(16.dp)
        )
    }
}

@Composable
fun EmailTextFieldSign(textIdentifiantResId: Int, email: String, onValueChange: (String) -> Unit){
    val textIdentifiant = stringResource(id = textIdentifiantResId)
    Column(modifier = Modifier.padding(top = 16.dp)) {
        OutlinedTextField(
            value = email,
            onValueChange = onValueChange,
            label = { Text(textIdentifiant) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Email),
            shape = RoundedCornerShape(16.dp)
        )
    }
}

@Composable
fun PassWdTextFieldSign(textpasswdResId : Int, passwd: String, onValueChange: (String) -> Unit, passwordVisible: Boolean, onPasswordVisibilityChange: () -> Unit){
    val textpasswd = stringResource(id = textpasswdResId)
    Column(modifier = Modifier.padding(top = 10.dp)) {
        OutlinedTextField(
            value = passwd,
            onValueChange = onValueChange,
            label = { Text(textpasswd) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            visualTransformation = if (passwordVisible) VisualTransformation.None else PasswordVisualTransformation(),
            trailingIcon = {
                IconButton(onClick = onPasswordVisibilityChange) {
                    Icon(imageVector = Icons.Default.Check, contentDescription = "Valider")
                }
            },
            shape = RoundedCornerShape(16.dp)
        )
    }
}

@Composable
fun PassWdConfirmTextFieldSign(textpasswdResId : Int,confirmPassword: String, onValueChange: (String) -> Unit, passwordVisible: Boolean, onPasswordVisibilityChange: () -> Unit){
    val textpasswd = stringResource(id = textpasswdResId)
    Column(modifier = Modifier.padding(top = 10.dp)) {
        OutlinedTextField(
            value = confirmPassword,
            onValueChange = onValueChange,
            label = { Text(textpasswd) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            visualTransformation = if (passwordVisible) VisualTransformation.None else PasswordVisualTransformation(),
            trailingIcon = {
                IconButton(onClick = onPasswordVisibilityChange) {
                    Icon(imageVector = Icons.Default.Check, contentDescription = "Valider")
                }
            },
            shape = RoundedCornerShape(16.dp)
        )
    }
}


// Validation de email
fun isValidEmail(email: String): Boolean {
    val emailRegex = "[a-zA-Z0-9._-]+@[a-zA-Z0-9.-]+\\.[a-zA-Z]{2,6}"
    return email.matches(emailRegex.toRegex())
}

// Vérification mots de passe
fun arePasswordsMatching(password: String, confirmPassword: String): Boolean {
    return password == confirmPassword
}

@Composable
fun ConnexionButtonSign(
    titleResId: Int,
    size: Int,
    colorButton: Color,
    colorText: Color,
    username: String,
    email: String,
    password: String,
    confirmPassword: String,
    service: IServices,
    navController: ()-> Unit
) {
    val title = stringResource(id = titleResId)
    var emailError by remember { mutableStateOf(false) }
    var passwordError by remember { mutableStateOf(false) }
    var passwordErrorEmpty by remember { mutableStateOf(false) }
    var usernameErrorEmpty by remember { mutableStateOf(false) }
    var usernameErrorExist by remember { mutableStateOf(false) }

    Button(
        onClick = {
            emailError = !isValidEmail(email)
            passwordError = !arePasswordsMatching(password, confirmPassword)
            usernameErrorEmpty = username.isBlank()
            passwordErrorEmpty = password.isBlank() || confirmPassword.isBlank()

            if (!emailError && !passwordError && !usernameErrorEmpty && !passwordErrorEmpty) {
                usernameErrorExist = !service.CreateUser(username, email, password, service)
                if(!usernameErrorExist){
                    navController() // retour à la page login
                }
            }
        },
        colors = ButtonDefaults.buttonColors(containerColor = colorButton),
        modifier = Modifier.fillMaxWidth(),
    ) {
        Text(title, fontSize = size.sp, color = colorText)
    }

    // Afficher erreurs
    if (usernameErrorEmpty) {
        ErrorMessageProfileComponent(R.string.ErrorUserEmptySignUp)
    }

    if (usernameErrorExist) {
        ErrorMessageProfileComponent(R.string.ErrorUserExistSignUp)
    }

    if (emailError) {
        ErrorMessageProfileComponent(R.string.ErrorEmailSignUp)

    }
    if (passwordError) {
        ErrorMessageProfileComponent(R.string.ErrorPasswordSignUp)
    }

    if (passwordErrorEmpty) {
        ErrorMessageProfileComponent(R.string.ErrorPasswordEmpty)
    }


}


@Composable
fun ReturnLogin(titleResId: Int, size: Int, color: Color, navController: () -> Unit) {
    val title = stringResource(id = titleResId)
    Text(
        text = title,
        fontSize = size.sp,
        color = color,
        modifier = Modifier.clickable {
            navController() //  Revenir à la page login
        }
    )
}
